@@ -755,34 +755,19 @@ function read_csvfile($fp, $logstr)
 /***********************************************************
  * parse_csv
  *
- * csv
+ * ѿ˳Ǽ줿CSVǡѡ
  *
  * []
- *        $line        csv1
+ *        $line        CSVǡ
  *
- * []
- *        $parse[1]    
+ * [֤]
+ *        $parse       ѡ
  *
  **********************************************************/
 function parse_csv($line)
 {
-    $parse = array();
-    $rep_str = array();
-
-    // "",,
-    preg_match_all('/("[^"]*(""[^"]*)*"|[^,]*),?/', $line, $parse);
-
-    // 
-    array_pop($parse[1]);
-
-    // "",
-    foreach($parse[1] as $key => $value) {
-        // "("")"
-        if(preg_match('/^"(.*)"$/', $value, $rep_str)) {
-            $parse[1][$key] = preg_replace('/""/', '"', $rep_str[1]);
-        }
-    }
-    return $parse[1];
+    $parse = str_getcsv($line);
+    return $parse;
 }
 
 /***********************************************************
