@@ -85,7 +85,7 @@ function set_tag_data($post, &$tag)
     // hiddenΥå
     $tag["<<HIDDEN>>"] = "";
     foreach($hiddendata as $hidkey => $hidval) {
-        $hidval = htmlspecialchars($hidval);
+        $hidval = escape_html($hidval);
         $tag["<<HIDDEN>>"] .= "<input type=\"hidden\" name=\"{$hidkey}\" value=\"{$hidval}\">\n";
     }
 
